function [bvp,info]=setBVPCondenser2D_01(N,verbose)
  if nargin==1, verbose=10*(N==0);end
  geofile='condenser';
  if verbose>=1
     fprintf('------------------------------------------------------\n'); 
    fprintf('      2D condenser BVP problem on GMSH mesh from %s.geo\n',geofile);
    fprintf('               - Delta(u) = 0\n')
    fprintf(' and boundary conditions :\n');
    fprintf('   * Dirichlet on [1,98,99]\n');
    fprintf('       u = 0 on [1], -12 on [98] and 12 on [99]  \n');
    fprintf('------------------------------------------------------\n');
    if verbose==10, return;end
  end

  if verbose>=2,fprintf('1. Building the mesh using GMSH\n');end
  tstart=tic();
  meshfile=gmsh.buildmesh2d(geofile,N,'force',true);
  Th=siMesh(meshfile);
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, h=%.3e\n',Th.nq,Th.get_h());
    fprintf('2. Setting 2D Condenser BVP problem\n');
  end
  tstart=tic();
  Lop=Loperator(2,2,{1,0;0,1},[],[],[]);
  pde=PDEelt(Lop);
  bvp=BVP(Th,pde);
  bvp.setDirichlet( 1, 0.);
  bvp.setDirichlet( 98, -12.);
  bvp.setDirichlet( 99, +12.);
  tcpu(2)=toc(tstart);

  info.solex=[];
  info.f=[];
  info.tcpu=tcpu;
end